==> spip_4.1.9+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_oc_lms.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=oc_lms
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_restaurer_base' => 'Restaurar la basa',

	// I
	'info_restauration_sauvegarde' => 'restauracion de la sauvagarda @archive@', # MODIF
	'info_sauvegarde' => 'Sauvagarda',
	'info_sauvegarde_reussi_02' => 'La basa es estada sauvagardada dins @archive@. Podetz',
	'info_sauvegarde_reussi_03' => 'tornar a la gestion',
	'info_sauvegarde_reussi_04' => 'de vòstre sit.',

	// T
	'texte_admin_tech_01' => 'Quela opcion vos permet de sauvagardar lo contengut de la basa dins un fichier que será servat dins lo repertòri @dossier@.
Oblidetz pas tanpauc de recuperar l’integralitat dau repertòri <i>IMG/</i>, que conten los imatges e los documents utilizats dins los articles e rubricas.',
	'texte_admin_tech_02' => 'Atencion: quela sauvagarda se poirá restaurar
 SOLAMENT dins un sit installat emb la mesma version d’SPIP. Donc subretot chau pas "voidar la basa" en esperar de reïnstallar la sauvagarda après una actualizacion. Consultatz <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar lo contengut d’una sauvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Quela opcion vos permet de restaurar una sauvagarda 
 de la basa que l’aviatz facha avans. Per quò faire, chau aver botat lo fichier que conten la sauvagarda 
dins lo repertòri @dossier@.
  Pasmens, siatz prudent(a) emb quela foncionalitat: <b>las modificacions e perdas eventualas son
  irreversiblas.</b>', # MODIF
	'texte_sauvegarde' => 'Sauvagardar lo contengut de la basa',
	'texte_sauvegarde_base' => 'Sauvagardar la basa'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/dump/lang/dump_oc_lms.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/dump?lang_cible=oc_lms
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_restaurer_base' => 'Restaurar la basa',

	// I
	'info_restauration_sauvegarde' => 'restauracion de la sauvagarda @archive@', # MODIF
	'info_sauvegarde' => 'Sauvagarda',
	'info_sauvegarde_reussi_02' => 'La basa es estada sauvagardada dins @archive@. Podetz',
	'info_sauvegarde_reussi_03' => 'tornar a la gestion',
	'info_sauvegarde_reussi_04' => 'de vòstre sit.',

	// T
	'texte_admin_tech_01' => 'Quela opcion vos permet de sauvagardar lo contengut de la basa dins un fichier que será servat dins lo repertòri @dossier@.
Oblidetz pas tanpauc de recuperar l’integralitat dau repertòri <i>IMG/</i>, que conten los imatges e los documents utilizats dins los articles e rubricas.',
	'texte_admin_tech_02' => 'Atencion: quela sauvagarda se poirá restaurar
 SOLAMENT dins un sit installat emb la mesma version d’SPIP. Donc subretot chau pas "voidar la basa" en esperar de reïnstallar la sauvagarda après una actualizacion. Consultatz <a href="@spipnet@">la documentacion d’SPIP</a>.', # MODIF
	'texte_restaurer_base' => 'Restaurar lo contengut d’una sauvagarda de la basa',
	'texte_restaurer_sauvegarde' => 'Quela opcion vos permet de restaurar una sauvagarda 
 de la basa que l’aviatz facha avans. Per quò faire, chau aver botat lo fichier que conten la sauvagarda 
dins lo repertòri @dossier@.
  Pasmens, siatz prudent(a) emb quela foncionalitat: <b>las modificacions e perdas eventualas son
  irreversiblas.</b>', # MODIF
	'texte_sauvegarde' => 'Sauvagardar lo contengut de la basa',
	'texte_sauvegarde_base' => 'Sauvagardar la basa',
];
